@@ -8,7 +8,7 @@ package MarpaX::Languages::ECMAScript::AST::Grammar;
 use MarpaX::Languages::ECMAScript::AST::Grammar::ECMAScript_262_5;
 use MarpaX::Languages::ECMAScript::AST::Exceptions qw/:all/;
 
-our $VERSION = '0.007'; # TRIAL VERSION
+our $VERSION = '0.008'; # TRIAL VERSION
 
 
 sub new {
@@ -59,6 +59,18 @@ sub pattern {
 }
 
 
+sub JSON {
+    my ($self) = @_;
+    return $self->{_grammar}->JSON;
+}
+
+
+sub URI {
+    my ($self) = @_;
+    return $self->{_grammar}->URI;
+}
+
+
 1;
 
 __END__
@@ -73,7 +85,7 @@ MarpaX::Languages::ECMAScript::AST::Grammar - ECMAScript grammar written in Marp
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -139,6 +151,14 @@ Returns the generic stringNumericLiteral associated to grammarName.
 
 Returns the generic pattern associated to grammarName.
 
+=head2 JSON($self)
+
+Returns the generic JSON associated to grammarName.
+
+=head2 URI($self)
+
+Returns the generic URI associated to grammarName.
+
 =head1 SEE ALSO
 
 L<Marpa::R2>
